package logging

import (
	sysd "github.com/coreos/go-systemd/journal"
	"github.com/google/uuid"
)

/*
AddDefaultLogger adds a default Logger (as would be determined by GetLogger) to a MultiLogger.

identifier is a string to use to identify the added Logger in MultiLogger.Loggers.
If empty, one will be automatically generated.

See the documentation for GetLogger for details on other arguments.
*/
func (m *MultiLogger) AddDefaultLogger(identifier string, logFlags int, logPaths ...string) (err error) {

	var l Logger
	var exists bool

	if identifier == "" {
		identifier = uuid.New().String()
	}

	if _, exists = m.Loggers[identifier]; exists {
		err = ErrExistingLogger
		return
	}

	if l, err = GetLogger(m.EnableDebug, m.Prefix, logFlags, logPaths...); err != nil {
		return
	}

	m.Loggers[identifier] = l

	return
}

/*
AddSysdLogger adds a SystemDLogger to a MultiLogger.

identifier is a string to use to identify the added SystemDLogger in MultiLogger.Loggers.
If empty, one will be automatically generated.
*/
func (m *MultiLogger) AddSysdLogger(identifier string) (err error) {

	var exists bool
	var prefix string

	if identifier == "" {
		identifier = uuid.New().String()
	}

	if _, exists = m.Loggers[identifier]; exists {
		err = ErrExistingLogger
		return
	}

	if !sysd.Enabled() {
		err = ErrNoSysD
		return
	}

	m.Loggers[identifier] = &SystemDLogger{
		EnableDebug: m.EnableDebug,
		Prefix:      m.Prefix,
	}
	if err = m.Loggers[identifier].Setup(); err != nil {
		return
	}

	if prefix, err = m.Loggers[identifier].GetPrefix(); err != nil {
		return
	}

	m.Loggers[identifier].Debug("logger initialized of type %T with prefix %v", m.Loggers[identifier], prefix)

	return
}
